/* CDate.h
*/

#ifndef MICHAEL_CDate_LIB_H
#define MICHAEL_CDate_LIB_H

#include "CTime.h"
#include "CString.h"

/**/ // class CDate {
class CDate {
public:
	enum Weekdays { Sunday = 0, Monday, Tuesday, 
		Wednesday, Thursday, Friday, Saturday };

	enum Months { January = 1, February, March, April, May, June, July,
		August, September, October, November, December };

	CDate();
	CDate( int32 since_1600 );		 // days since 1.1.1600
	CDate( int32 day, int32 month, int32 year );
	CDate( const CDate& date);

	int32 Year( int32 year );
	int32 Month( int32 month );
	int32 Day( int32 day );

	int32 Year() const;
	int32 Month() const;
	int32 Day() const;

	int32 DayNumber() const;
	int32 Weekday() const;
	CDate &NextWeekday( int16 weekday, int16 mode = 0 );
	CDate &PrevWeekday( int16 weekday, int16 mode = 0 );
	CDate &Easter();
	int32 Since1600() const;	// get days since 1.1.1600

	int16 IsValidDay() const;
	int16 IsValidMonth() const;
	int16 IsValidYear() const;
	int16 IsValid() const;
	void PrevValidDate();
	void NextValidDate();

	void AddMonths( int32, int16 prevnext = 0 );

	CDate& operator=( const CDate& date );

	CDate& operator+=( int32 days );
	CDate& operator+=( const CTime& time );
	CDate operator+( int32 days ) const;
	CDate& operator-=( int32 days );
	CDate& operator-=( const CTime& time );
	CDate operator-( int32 days ) const;
	int32 operator-( const CDate& date ) const;		// get difference in days

	int16 operator==( const CDate& date ) const;
	int16 operator!=( const CDate& date ) const;
	int16 operator<=( const CDate& date ) const;
	int16 operator>=( const CDate& date ) const;
	int16 operator<( const CDate& date ) const;
	int16 operator>( const CDate& date ) const;
	int16 operator!() const;

	const static char *weekdays[];
	const static char *weekdays2[];
	const static char *weekdays3[];
	const static char *months[];
	const static char *months3[];
private:
	int32 day, month, year;
	const static int32 julian_1600;	// 1.1. 1600 als Julian()
	int32 Julian() const;

};///

#endif
